Module rustc_ap_rustc_errors::emitter [−][src]
The current rustc diagnostics emitter.
An Emitter takes care of generating the output from a DiagnosticBuilder struct.
There are various Emitter implementations that generate different output formats such as
JSON and human readable output.
The output types are defined in rustc_session::config::ErrorOutputType.
Structs
Handles the writing of HumanReadableErrorType::Default and HumanReadableErrorType::Short
An emitter that does nothing when emitting a diagnostic.
Enums
Describes the way the content of the rendered field of the json output is generated
Constants
Maximum number of suggestions to be shown
Maximum number of lines we will print for a multiline suggestion; arbitrary.
Traits
Emitter trait for emitting errors.
Functions
Whether the original and suggested code are visually similar enough to warrant extra wording.